#!/bin/sh
#   Copyright (c) 2011 digitalSTROM.org, Zurich, Switzerland
#
#   Author: Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
#
#   This file is part of digitalSTROM Server.
#
#   netinfo.sh is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   netinfo.sh is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this file. If not, see <http://www.gnu.org/licenses/>.

# source common functions
. ./errlib.sh
. ./jsonlib.sh
. ./util.sh

LOCATION_DIRECTORY="/usr/share/dss/data/config.d"
LOCATION_CONFIG="location.xml"
LOCATION="$LOCATION_DIRECTORY/$LOCATION_CONFIG"
LOCATION_TMP="/tmp/$LOCATION_CONFIG"
echo "Content-Type: application/json"
echo ""

validate_loc() {
    if [[ -n "$1" ]]; then
        echo "$1" | grep "[^[:alpha:][\w\xc0-\xff] \-]" > /dev/null 2>&1
        if [ "$?" -eq "0" ]; then
            return $ERR_INVALID 
        fi
    else
        return $ERR_INVALID 
    fi

    return $ERR_OK
}

validate_float() {
    if [[ -n "$1" ]]; then
        echo "$1" | grep "(\+|-)?([0-9]+\.?[0-9]*" > /dev/null 2>&1
        if [ "$?" -eq "0" ]; then
            return $ERR_INVALID 
        fi
    else
        return $ERR_INVALID 
    fi

    return $ERR_OK
}


write_location() {
    echo -e "\
<?xml version=\"1.0\" encoding=\"utf-8\"?>\n\
<properties version=\"1\">\n\
  <property name=\"config\">\n\
    <property name=\"geodata/country\" type=\"string\">\n\
      <value>$1</value>\n\
    </property>\n\
    <property name=\"geodata/location\" type=\"string\">\n\
      <value>$2</value>\n\
    </property>\n\
    <property name=\"geodata/latitude\" type=\"string\">\n\
      <value>$3</value>\n\
    </property>\n\
    <property name=\"geodata/longitude\" type=\"string\">\n\
      <value>$4</value>\n\
    </property>
     <property name=\"geodata/offsetGMT\" type=\"string\">\n\
      <value>$5</value>\n\
    </property>\n\
  </property>\n\
</properties>" >> $LOCATION_TMP
    if [[ "$?" -ne "0" ]]; then
        return $ERR_FWRITE
    fi
    return $ERR_OK
}

COUNTRY=
LOC=
LATITUDE=
LONGITUDE=
GMTOFFSET=

# Parameters: COUNTRY, LOCATION, LATITUDE, LONGITUDE, GMTOFFSET, [ TIMEZONE ]

if [[ ! -d "$LOCATION_DIRECTORY" ]]; then
    mkdir -p "$LOCATION_DIRECTORY" > /dev/null 2>&1
    if [[ "$?" -ne "0" ]]; then
        json_error $ERR_CANTCREAT "Could not create config directory"
        exit 1
    fi
fi

if [[ "$1" == "-" ]]; then
    COUNTRY="other"
    LOC="unknown"
else
    validate_loc "$1"
    if [[ "$?" -ne "$ERR_OK" ]]; then
        json_error $ERR_INVALID "Invalid country specified"
        exit 1
    fi
    COUNTRY="$1"

    validate_loc "$2"
    if [[ "$?" -ne "$ERR_OK" ]]; then
        json_error $ERR_INVALID "Invalid location specified"
        exit 1
    fi
    LOC="$2"
fi

validate_float "$3"
if [[ "$?" -ne "$ERR_OK" ]]; then
    json_error $ERR_INVALID "Invalid latitude specified"
    exit 1
fi

LATITUDE="$3"

validate_float "$4"
if [[ "$?" -ne "$ERR_OK" ]]; then
    json_error $ERR_INVALID "Invalid longitude specified"
    exit 1
fi

LONGITUDE="$4"

validate_float "$5"
if [[ "$?" -ne "$ERR_OK" ]]; then
    json_error $ERR_INVALID "Invalid GMT offset specified"
    exit 1
fi

GMTOFFSET="$5"

write_location "$COUNTRY" "$LOC" "$LATITUDE" "$LONGITUDE" "$GMTOFFSET"
RETCODE="$?"
if [[ "$RETCODE" -ne "$ERR_OK" ]]; then
    json_error $RETCODE "Could not write location config"
    exit 1
fi

mv -f $LOCATION_TMP $LOCATION
if [[ "$?" -ne "0" ]]; then
    rm -f $LOCATION_TMP
    rm -f $LOCATION
    control_dss $RUNIT_RESTART
    json_error $ERR_IOERR "Could not set location config"
    exit 1
fi

REMEMBER_ERROR=$ERR_OK
if [[ -n "$6" ]]; then
    set_timezone "$6"
    RETCODE="$?"
    if [[ "$RETCODE" -ne "$ERR_OK" ]]; then
        if [[ $RETCODE -eq $ERR_NOZONES ]]; then
            json_error $ERR_NOZONES "Requested time zone is not installed!"
        elif [[ $RETCODE -eq $ERR_LINK ]]; then
            json_error $ERR_LINK "Could not set requested zone, link failed!"
        fi
        REMEMBER_ERROR=$RETCODE
    fi
fi

control_dss $RUNIT_RESTART

if [[ $REMEMBER_ERROR -eq $ERR_OK ]]; then
    json_ok
fi

