Ext.namespace('dSS11', 'dSS11.config');

dSS11.ListMenuPanel = Ext.extend(Ext.Panel,
    {
        constructor: function(config)
        {
            var tabRecord = Ext.data.Record.create([
                    {
                        name: 'title',
                        id: 'id',
                        auto: 'auto'
                    }
                ]);

            var tabStore = new Ext.data.Store({}, tabRecord);

            var menuItems = [];

            if (config.menuItems !== undefined) {
                menuItems = menuItems.concat(config.menuItems);
            }

            var contentPanel =
            {
                ref: 'contentPanel',
                region: 'center',
                layout: 'card',
                hideBorders: true,
                split: true,
                items: menuItems
            };

            this.listView = new Ext.list.ListView(
                {
                    ref: 'listView',
                    store: tabStore,
                    singleSelect: true,
                    region: 'west',
                    hideHeaders: true,
                    columns: [{ header: 'name', dataIndex: 'title' }]
                }
            );

            var listHolder = new Ext.Panel(
                {
                    title: _("Menu"),
                    region: 'west',
                    layout: 'fit',
                    width: 190,
                    hideBorders: true,
                    split: true,
                    items: [ this.listView ]
                }
            );
            
            this.defaultSelection = 0;

            Ext.apply(this,
                {
                    layout: 'border',
                    items: [ listHolder, contentPanel ]
                }
            );

            dSS11.ListMenuPanel.superclass.constructor.call(this, config);
       
            this.on(
                'beforerender',
                function(component)
                {
                    if (this.initializedTabs)
                    {
                        return;
                    }

                    // for each item in contentPanel
                    this.contentPanel.items.each(
                        function(item)
                        {
                            var tab = new tabRecord(
                                {
                                    title: item.title,
                                    id: item.id,
                                    auto: item.auto
                                }
                            );
                            tabStore.add([tab]);
                        },
                        this
                    );

                    this.listView.on(
                        'afterrender',
                        function()
                        {
                            this.listView.select(this.defaultSelection);
                        },
                        this
                    );

                    this.listView.on(
                        'selectionchange',
                        function(listView, selections)
                        {
                            this.contentPanel.layout.setActiveItem(selections[0].viewIndex);
                        },
                        this
                    );

                    this.listView.on(
                        'click',
                        function(listView, index)
                        {
                            if (listView.getRecord(listView.getNode(index)).get('auto') === true) {
                                Ext.getCmp(listView.getRecord(listView.getNode(index)).get('id')).doAutoLoad();
                            }
                        }
                    );
                    this.initializedTabs = true;
                },
                this
            ); // this.on
        }, // contructor
        getItem: function(key)
        {
            return this.contentPanel.items.get(key);
        }
    }
);

Ext.reg('dss11listmenupanel', dSS11.ListMenuPanel);
